"""View to return detailed information about a skill"""
from http import HTTPStatus

from markdown import markdown
import requests as service_request

from selene_util.api import SeleneEndpoint, APIError


class SkillDetailEndpoint(SeleneEndpoint):
    authentication_required = False

    def __init__(self):
        super(SkillDetailEndpoint, self).__init__()
        self.skill_id = None
        self.response_skill = None

    def get(self, skill_id):
        self.skill_id = skill_id
        try:
            self._authenticate()
            self._get_skill_details()
        except APIError:
            pass
        else:
            self._build_response_data()
            self.response = (self.response_skill, HTTPStatus.OK)

        return self.response

    def _get_skill_details(self):
        """Build the data to include in the response."""
        skill_service_response = service_request.get(
            self.config['SELENE_BASE_URL'] + '/skill/id/' + self.skill_id
        )
        self._check_for_service_errors(skill_service_response)
        self.response_skill = skill_service_response.json()

    def _build_response_data(self):
        self.response_skill['description'] = markdown(
            self.response_skill['description'],
            output_format='html5'
        )
        self.response_skill['summary'] = markdown(
            self.response_skill['summary'],
            output_format='html5'
        )