import { Component, Input, OnInit } from '@angular/core';
import { MatSnackBar } from "@angular/material";

import { faCheck, faComment } from '@fortawesome/free-solid-svg-icons';

import { SkillsService, Skill } from "../skills.service";

@Component({
    selector: 'market-skill-summary',
    templateUrl: './skill-summary.component.html',
    styleUrls: ['./skill-summary.component.scss'],
})
export class SkillSummaryComponent implements OnInit {
    public installedIcon = faCheck;
    @Input() public skills: Skill[];
    public voiceIcon = faComment;
    private skillInstalling: Skill;

    constructor(public loginSnackbar: MatSnackBar, private skillsService: SkillsService) { }

    ngOnInit() { }

    /**
     * Install a skill onto one or many devices
     *
     * @param {Skill} skill
     */
    install_skill(skill: Skill) : void {
        this.skillInstalling = skill;
        this.skillsService.installSkill(skill).subscribe(
            (response) => {
                this.onInstallSuccess(response)
            },
            (response) => {
                this.onInstallFailure(response)
            }
        );
    }

    /**
     * Handle the successful install attempt
     *
     * This does not indicate that the install of the skill completed, only
     * that the request to install a skill succeeded.  Change the install
     * button to an "installing" state.
     *
     * @param response
     */
    onInstallSuccess(response) : void {
        this.loginSnackbar.open(
            'The ' + this.skillInstalling.title + ' skill is ' +
            'installing.  Please allow up to two minutes for installation' +
            'to complete before using the skill.  Only one skill can be ' +
            'installed at a time so please wait before selecting another' +
            'skill to install',
            null,
            {panelClass: 'mycroft-snackbar', duration:20000}
        );
    }

    /**
     * Handle the failure to install a skill.
     *
     * If a user attempts to install a skill without being logged in, show a
     * snackbar to notify the user and give them the ability to log in.
     *
     * @param response - object representing the response from the API call
     */
    onInstallFailure(response) : void {
        if (response.status === 401) {
            this.loginSnackbar.open(
                'To install a skill, log in to your account.',
                'LOG IN',
                {panelClass: 'mycroft-snackbar', duration: 5000}
            );
        }
    }
}
